"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useMediaQuery = void 0;
const react_native_1 = require("react-native");
const MIN_WIDTH = 'minWidth';
const MAX_WIDTH = 'maxWidth';
const MIN_HEIGHT = 'minHeight';
const MAX_HEIGHT = 'maxHeight';
const ORIENTATION = 'orientation';
const LANDSCAPE = 'landscape';
const PORTRAIT = 'portrait';
const useMediaQuery = (query) => {
    const { width, height } = (0, react_native_1.useWindowDimensions)();
    return parseQuery(query, width, height);
};
exports.useMediaQuery = useMediaQuery;
const parseQuery = (query, width, height) => Object.keys(query)
    .map(key => matchQuery(key, query[key], width, height))
    .reduce((sum, next) => sum && next, true);
const matchQuery = (key, value, width, height) => {
    switch (key) {
        case MIN_WIDTH:
            return value <= width;
        case MAX_WIDTH:
            return value >= width;
        case MIN_HEIGHT:
            return value <= height;
        case MAX_HEIGHT:
            return value >= height;
        case ORIENTATION:
            return determineOrientation(value, width, height);
        default:
            console.warn(`Incorrect media query type. Use query types: ${MIN_WIDTH}, ${MAX_WIDTH}, ${MIN_HEIGHT}, ${MIN_HEIGHT}, or ${ORIENTATION}.`);
            return false;
    }
};
const determineOrientation = (value, width, height) => {
    if (width > height) {
        return value === LANDSCAPE;
    }
    return value === PORTRAIT;
};
